@@ -14,6 +14,7 @@ if TYPE_CHECKING:
 
 import sentry_sdk
 from sentry_sdk.utils import logger
+from sentry_sdk.consts import SPANDATA
 
 MAX_GEN_AI_MESSAGE_BYTES = 20_000  # 20KB
 # Maximum characters when only a single message is left after bytes truncation
@@ -682,6 +683,28 @@ def truncate_messages_by_size(
 
 
 def truncate_and_annotate_messages(
+    messages: "Optional[List[Dict[str, Any]]]",
+    span: "Any",
+    scope: "Any",
+    max_single_message_chars: int = MAX_SINGLE_MESSAGE_CONTENT_CHARS,
+) -> "Optional[List[Dict[str, Any]]]":
+    if not messages:
+        return None
+
+    messages = redact_blob_message_parts(messages)
+
+    truncated_message = _truncate_single_message_content_if_present(
+        deepcopy(messages[-1]), max_chars=max_single_message_chars
+    )
+    if len(messages) > 1:
+        scope._gen_ai_original_message_count[span.span_id] = len(messages)
+
+    span.set_data(SPANDATA.META_GEN_AI_ORIGINAL_INPUT_MESSAGES_LENGTH, len(messages))
+
+    return [truncated_message]
+
+
+def truncate_and_annotate_embedding_inputs(
     messages: "Optional[List[Dict[str, Any]]]",
     span: "Any",
     scope: "Any",
@@ -697,3 +720,11 @@ def truncate_and_annotate_messages(
         scope._gen_ai_original_message_count[span.span_id] = len(messages)
 
     return truncated_messages
+
+
+def set_conversation_id(conversation_id: str) -> None:
+    """
+    Set the conversation_id in the scope.
+    """
+    scope = sentry_sdk.get_current_scope()
+    scope.set_conversation_id(conversation_id)
