@@ -518,6 +518,12 @@ class SPANDATA:
     Example: ["The weather in Paris is rainy and overcast, with temperatures around 57°F", "The weather in London is sunny and warm, with temperatures around 65°F"]
     """
 
+    GEN_AI_RESPONSE_TIME_TO_FIRST_TOKEN = "gen_ai.response.time_to_first_token"
+    """
+    The time it took to receive the first token from the model.
+    Example: 0.1
+    """
+
     GEN_AI_RESPONSE_TOOL_CALLS = "gen_ai.response.tool_calls"
     """
     The tool calls in the model's response.
@@ -542,6 +548,12 @@ class SPANDATA:
     Example: 2048
     """
 
+    GEN_AI_SYSTEM_INSTRUCTIONS = "gen_ai.system_instructions"
+    """
+    The system instructions passed to the model.
+    Example: [{"type": "text", "text": "You are a helpful assistant."},{"type": "text", "text": "Be concise and clear."}]
+    """
+
     GEN_AI_REQUEST_MESSAGES = "gen_ai.request.messages"
     """
     The messages passed to the model. The "content" can be a string or an array of objects.
@@ -857,6 +869,14 @@ class SPANDATA:
     Example: "a1b2c3d4e5f6"
     """
 
+    META_GEN_AI_ORIGINAL_INPUT_MESSAGES_LENGTH = (
+        "sentry.sdk_meta.gen_ai.input.messages.original_length"
+    )
+    """
+    The original number of input non-system instruction messages, before SDK trimming.
+    Example: 4
+    """
+
 
 class SPANSTATUS:
     """
@@ -1471,4 +1491,4 @@ DEFAULT_OPTIONS = _get_default_options()
 del _get_default_options
 
 
-VERSION = "2.50.0"
+VERSION = "2.51.0"
