@@ -4,9 +4,9 @@ from sentry_sdk.consts import OP, SPANDATA
 from sentry_sdk.integrations import Integration, DidNotEnable
 from sentry_sdk.tracing import BAGGAGE_HEADER_NAME
 from sentry_sdk.tracing_utils import (
-    Baggage,
     should_propagate_trace,
     add_http_request_source,
+    add_sentry_baggage_to_headers,
 )
 from sentry_sdk.utils import (
     SENSITIVE_DATA_SUBSTITUTE,
@@ -19,7 +19,6 @@ from sentry_sdk.utils import (
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
-    from collections.abc import MutableMapping
     from typing import Any
 
 
@@ -81,7 +80,7 @@ def _install_httpx_client() -> None:
                     )
 
                     if key == BAGGAGE_HEADER_NAME:
-                        _add_sentry_baggage_to_headers(request.headers, value)
+                        add_sentry_baggage_to_headers(request.headers, value)
                     else:
                         request.headers[key] = value
 
@@ -155,22 +154,3 @@ def _install_httpx_async_client() -> None:
         return rv
 
     AsyncClient.send = send
-
-
-def _add_sentry_baggage_to_headers(
-    headers: "MutableMapping[str, str]", sentry_baggage: str
-) -> None:
-    """Add the Sentry baggage to the headers.
-
-    This function directly mutates the provided headers. The provided sentry_baggage
-    is appended to the existing baggage. If the baggage already contains Sentry items,
-    they are stripped out first.
-    """
-    existing_baggage = headers.get(BAGGAGE_HEADER_NAME, "")
-    stripped_existing_baggage = Baggage.strip_sentry_baggage(existing_baggage)
-
-    separator = "," if len(stripped_existing_baggage) > 0 else ""
-
-    headers[BAGGAGE_HEADER_NAME] = (
-        stripped_existing_baggage + separator + sentry_baggage
-    )
