@@ -15,8 +15,7 @@ if TYPE_CHECKING:
     from typing import Any
 
 
-def _patch_model_request():
-    # type: () -> None
+def _patch_model_request() -> None:
     """
     Patches model request execution to create AI client spans.
 
@@ -29,8 +28,9 @@ def _patch_model_request():
         original_request = models.Model.request
 
         @wraps(original_request)
-        async def wrapped_request(self, messages, *args, **kwargs):
-            # type: (Any, Any, *Any, **Any) -> Any
+        async def wrapped_request(
+            self: "Any", messages: "Any", *args: "Any", **kwargs: "Any"
+        ) -> "Any":
             # Pass all messages (full conversation history)
             with ai_client_span(messages, None, self, None) as span:
                 result = await original_request(self, messages, *args, **kwargs)
